"""
Here the FastAPI application initialization.

Attributes:
    FASTAPI_APP (FastAPI): The main FastAPI application instance used to define routes,
        middlewares, and other application configurations.
"""

from fastapi import FastAPI


FASTAPI_APP = FastAPI()
