"""
Settings for the FastAPI project template.
This module contains the default settings and configurations for the FastAPI project template.
generated by FastAPIBig.
"""

from pathlib import Path
import sys

# Base directory for SQLite storage
BASE_DIR = Path(__file__).resolve().parent.parent

# add BASE_DIR root to sys path
sys.path.append(str(BASE_DIR.parent.parent))

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "default-secret-key"

ALLOWED_HOSTS = []

# Default to SQLite if the user doesn't configure a database
DATABASE_URL = f"sqlite+aiosqlite:///{BASE_DIR}/db.sqlite3"
